@@ -349,7 +349,7 @@ def AcceptPress():
 			ClassFlag = 0x4000
 		else:
 			ClassFlag = 0
-		#todo: set up ALL spell levels not just level 1
+
 		Spellbook.SetupSpellLevels (MyChar, TableName, IE_SPELL_TYPE_PRIEST, 1)
 		Learnable = Spellbook.GetLearnablePriestSpells (ClassFlag, t, 1)
 		PriestMemorized = GemRB.GetVar ("PriestMemorized")
@@ -381,7 +381,7 @@ def AcceptPress():
 	c = TmpTable.GetValue (ClassName, "MODIFIER") #adjustment
 	d = TmpTable.GetValue (ClassName, "MULTIPLIER") #external multiplier
 	e = TmpTable.GetValue (ClassName, "BONUS_PER_LEVEL") #level bonus rate (iwd only!)
-	t = GemRB.GetPlayerStat (MyChar, IE_LEVEL) #FIXME: calculate multiclass average
+	t = GemRB.GetPlayerStat (MyChar, IE_LEVEL)
 	if t>1:
 		e=e*(t-1)
 	else:
@@ -389,19 +389,6 @@ def AcceptPress():
 	t = GemRB.Roll (a,b,c)*d+e
 	GemRB.SetPlayerStat (MyChar, IE_GOLD, t)
 	GemRB.SetPlayerStat (MyChar, IE_EA, 2 )
-	#GemRB.SetPlayerStat (MyChar, IE_HATEDRACE, GemRB.GetVar ("HatedRace") )
-	#Str = GemRB.GetVar ("Ability1")
-	#GemRB.SetPlayerStat (MyChar, IE_STR, Str)
-	#if Str == 18:
-	#	GemRB.SetPlayerStat (MyChar, IE_STREXTRA, GemRB.GetVar ("StrExtra"))
-	#else:
-	#	GemRB.SetPlayerStat (MyChar, IE_STREXTRA, 0)
-
-	#GemRB.SetPlayerStat (MyChar, IE_DEX, GemRB.GetVar ("Ability2"))
-	#GemRB.SetPlayerStat (MyChar, IE_CON, GemRB.GetVar ("Ability3"))
-	#GemRB.SetPlayerStat (MyChar, IE_INT, GemRB.GetVar ("Ability4"))
-	#GemRB.SetPlayerStat (MyChar, IE_WIS, GemRB.GetVar ("Ability5"))
-	#GemRB.SetPlayerStat (MyChar, IE_CHR, GemRB.GetVar ("Ability6"))
 
 	GemRB.SetPlayerName (MyChar, GemRB.GetToken ("CHARNAME"), 0)
 	GemRB.SetToken ("CHARNAME","")
@@ -829,13 +816,13 @@ def PortraitCustomPress():
 
 	CustomWindow = Window = GemRB.LoadWindow (18)
 	PortraitList1 = Window.GetControl (2)
-	RowCount1 = PortraitList1.ListResources (CHR_PORTRAITS, 0)
+	RowCount1 = PortraitList1.ListResources (CHR_PORTRAITS, 1)
 	PortraitList1.SetEvent (IE_GUI_TEXTAREA_ON_SELECT, CGLargeCustomPortrait)
 	GemRB.SetVar ("Row1", RowCount1)
 	PortraitList1.SetVarAssoc ("Row1",RowCount1)
 
 	PortraitList2 = Window.GetControl (4)
-	RowCount2 = PortraitList2.ListResources (CHR_PORTRAITS, 1)
+	RowCount2 = PortraitList2.ListResources (CHR_PORTRAITS, 0)
 	PortraitList2.SetEvent (IE_GUI_TEXTAREA_ON_SELECT, CGSmallCustomPortrait)
 	GemRB.SetVar ("Row2", RowCount2)
 	PortraitList2.SetVarAssoc ("Row2",RowCount2)
@@ -1363,7 +1350,8 @@ def AbilitiesCalcLimits(Index):
 	global AbilitiesRaceReqTable, AbilitiesRaceAddTable, AbilitiesClassReqTable
 	global AbilitiesMinimum, AbilitiesMaximum, AbilitiesModifier
 
-	RaceName = CommonTables.Races.GetRowName (GemRB.GetPlayerStat (MyChar, IE_RACE) - 1)
+	Race = CommonTables.Races.FindValue (3, GemRB.GetPlayerStat (MyChar, IE_RACE))
+	RaceName = CommonTables.Races.GetRowName (Race)
 	Race = AbilitiesRaceReqTable.GetRowIndex (RaceName)
 	AbilitiesMinimum = AbilitiesRaceReqTable.GetValue (Race, Index * 2)
 	AbilitiesMaximum = AbilitiesRaceReqTable.GetValue (Race, Index * 2 + 1)
